@@ -6,6 +6,7 @@ from pydantic import UUID4
 
 from fief.crypto.access_token import generate_access_token
 from fief.crypto.id_token import generate_id_token
+from fief.crypto.token import generate_token
 from fief.dependencies.current_workspace import get_current_workspace
 from fief.dependencies.tenant import get_current_tenant
 from fief.dependencies.token import (
@@ -18,9 +19,7 @@ from fief.managers import RefreshTokenManager
 from fief.models import RefreshToken, Tenant, Workspace
 from fief.schemas.auth import TokenResponse
 from fief.schemas.user import UserDB
-
-TOKEN_LIFETIME = 3600
-REFRESH_TOKEN_LIFETIME = 3600 * 24 * 30
+from fief.settings import settings
 
 router = APIRouter()
 
@@ -37,11 +36,17 @@ async def token(
     scope = grant_request["scope"]
     authenticated_at = grant_request["authenticated_at"]
     nonce = grant_request["nonce"]
+    code = grant_request["code"]
     client = grant_request["client"]
 
     tenant_host = tenant.get_host(workspace.domain)
     access_token = generate_access_token(
-        tenant.get_sign_jwk(), tenant_host, client, user, scope, TOKEN_LIFETIME
+        tenant.get_sign_jwk(),
+        tenant_host,
+        client,
+        user,
+        scope,
+        settings.access_id_token_lifetime_seconds,
     )
     id_token = generate_id_token(
         tenant.get_sign_jwk(),
@@ -49,19 +54,25 @@ async def token(
         client,
         authenticated_at,
         user,
-        TOKEN_LIFETIME,
+        settings.access_id_token_lifetime_seconds,
         nonce=nonce,
+        code=code,
+        access_token=access_token,
         encryption_key=client.get_encrypt_jwk(),
     )
     token_response = TokenResponse(
-        access_token=access_token, id_token=id_token, expires_in=TOKEN_LIFETIME
+        access_token=access_token,
+        id_token=id_token,
+        expires_in=settings.access_id_token_lifetime_seconds,
     )
 
     if "offline_access" in scope:
         expires_at = datetime.now(timezone.utc) + timedelta(
-            seconds=REFRESH_TOKEN_LIFETIME
+            seconds=settings.refresh_token_lifetime_seconds
         )
+        token, token_hash = generate_token()
         refresh_token = RefreshToken(
+            token=token_hash,
             expires_at=expires_at,
             scope=scope,
             user_id=user.id,
@@ -69,7 +80,7 @@ async def token(
             authenticated_at=authenticated_at,
         )
         refresh_token = await refresh_token_manager.create(refresh_token)
-        token_response.refresh_token = refresh_token.token
+        token_response.refresh_token = token
 
     response.headers["Cache-Control"] = "no-store"
     response.headers["Pragma"] = "no-cache"
