@@ -7,6 +7,7 @@ from fastapi_users.manager import UserNotExists
 from pydantic import UUID4
 
 from fief.crypto.code_challenge import verify_code_verifier
+from fief.crypto.token import get_token_hash
 from fief.dependencies.users import UserManager, get_user_manager
 from fief.dependencies.workspace_managers import (
     get_authorization_code_manager,
@@ -27,6 +28,7 @@ class GrantRequest(TypedDict):
     scope: List[str]
     authenticated_at: datetime
     nonce: Optional[str]
+    code: Optional[str]
     client: Client
 
 
@@ -93,7 +95,10 @@ async def validate_grant_request(
         if redirect_uri is None:
             raise TokenRequestException(TokenError.get_invalid_request())
 
-        authorization_code = await authorization_code_manager.get_valid_by_code(code)
+        code_hash = get_token_hash(code)
+        authorization_code = await authorization_code_manager.get_valid_by_code(
+            code_hash
+        )
         if authorization_code is None:
             raise TokenRequestException(TokenError.get_invalid_grant())
 
@@ -115,6 +120,7 @@ async def validate_grant_request(
             "scope": authorization_code.scope,
             "authenticated_at": authorization_code.authenticated_at,
             "nonce": authorization_code.nonce,
+            "code": authorization_code.code,
             "client": client,
         }
 
@@ -124,7 +130,8 @@ async def validate_grant_request(
         if refresh_token_token is None:
             raise TokenRequestException(TokenError.get_invalid_request())
 
-        refresh_token = await refresh_token_manager.get_by_token(refresh_token_token)
+        token_hash = get_token_hash(refresh_token_token)
+        refresh_token = await refresh_token_manager.get_by_token(token_hash)
 
         if refresh_token is None:
             raise TokenRequestException(TokenError.get_invalid_grant())
@@ -141,6 +148,7 @@ async def validate_grant_request(
             "scope": new_scope,
             "authenticated_at": refresh_token.authenticated_at,
             "nonce": None,
+            "code": None,
             "client": client,
         }
 
